@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# $Id: makelgc.sh 688 2006-03-22 22:01:37Z moyogo $
+# $Id: makelgc.sh 1290 2006-11-19 14:46:56Z ben_laenen $
 
 mkdir lgc
 echo "Creating LGC derivative"
@@ -17,8 +17,11 @@ fontforge -script - *.sfd <<END
 i = 1
 while ( i < \$argc )
   Open(\$argv[i], 1)
+
   Select(0u0530, 0u1cff)
-  SelectMore(0u2c00, 0udfff)
+  SelectMore(0u2c00, 0u2c5f)
+  SelectMore(0u2cff, 0ua6ff)
+  SelectMore(0ua800, 0udfff)
   SelectMore(0uf900, 0ufaff)
   SelectMore(0ufb07, 0ufe1f)
   SelectMore(0ufe30, 0uffef)
@@ -45,5 +48,5 @@ echo "Making LGC distribution of DejaVu fonts $version"
 name=dejavu-lgc-ttf-$version
 mkdir packaged/$name
 cp lgc/generated/*.ttf README LICENSE AUTHORS NEWS BUGS lgc/unicover.txt lgc/langcover.txt packaged/$name
-(cd packaged; tar czvf $name.tar.gz $name)
+(cd packaged; tar cjvf $name.tar.bz2 $name)
 (cd packaged; zip -rv $name.zip $name)
